#!/bin/bash
# author           : Fred. Galusik <fredg> (fred@zenwalk.fr)
# homepage         : http://www.losersjuegos.com.ar
# last revised     : 03.11.2007

softname='ceferino'
softversion='0.97.8'
packageversion='50.1'

arch='i686'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/32x32/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: Super pang clone
$softname: 
$softname: Don Ceferino Hazana is an action game similar 
$softname: to Super Pang.
$softname:  
$softname:   
$softname: 
$softname: 
$softname: 
$softname:
$softname: 
EOF

# extract the source code
cd $buildir
tar zxvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"   
    
    ./configure \
      --prefix=$prefix \
      --datadir=/usr/share \
      --program-prefix="" \
      --program-suffix="" \
     
    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      ABOUT-NLS COPYING AUTHORS THANKS INSTALL NEWS README ChangeLog\
      $dest/usr/doc/$softname-$softversion 

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# make the .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop 
[Desktop Entry]
Name=Ceferino
Comment=a super pang similar game
Exec=ceferino
Icon=ceferino
Categories=Game;ArcadeGame;
Terminal=false
Type=Application
Encoding=UTF-8
EOF

# Make the package freedesktop compliant
cp $buildir/$softname-$softversion/data/ima/icono.png $dest/usr/share/icons/hicolor/32x32/apps/$softname.png

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
